==> navigine_sdk-1.2.1%2B3.tar.gz: lib/models/device_info.dart <==
part of navigine_sdk;

class DeviceInfo {
  String id = "";
  int location = 0;
  int subLocation = 0;
  double x = 0.0;
  double y = 0.0;
  double r = 0.0;
  double azimuth = 0.0;
  double stepLength = 0.0;
  int stepCount = 0;
  int errorCode = 0;
  List<RoutePath> paths = [];
  List<Zone> zones = [];
  double latitude = 0;
  double longitude = 0;

  static DeviceInfo fromMap(data) {
    DeviceInfo di = DeviceInfo();
    di.azimuth = data["azimuth"] as double;
    di.errorCode = data["errorCode"] as int;
    di.id = data["id"] as String;
    di.location = data["location"] as int;
    di.r = data["r"] as double;
    di.stepCount = data["stepCount"] as int;
    di.subLocation = data["subLocation"] as int;
    di.stepLength = data["stepLength"] as double;
    di.x = data["x"] as double;
    di.y = data["y"] as double;

    for (var zone in data["zones"]) {
      di.zones.add(Zone.fromMap(zone));
    }

    for (var path in data["paths"]) {
      di.paths.add(RoutePath.fromMap(path));
    }
    return di;
  }

  bool isValid() {
    return this.location > 0 && this.subLocation > 0 && this.errorCode == 0;
  }

  LocationPoint? getLocationPoint() {
    return this.isValid()
        ? LocationPoint.fromData(
            this.location, this.subLocation, this.x, this.y)
        : null;
  }

  GlobalPoint? getGlobalPoint() {
    return this.isValid()
        ? GlobalPoint.fromValue(this.latitude, this.longitude)
        : null;
  }

  bool inZoneInId(int id) {
    for (int i = 0; i < this.zones.length; ++i) {
      if ((this.zones[i]).id == id) {
        return true;
      }
    }

    return false;
  }

  bool inZoneInAlias(String alias) {
    for (int i = 0; i < this.zones.length; ++i) {
      if ((this.zones[i]).alias == alias) {
        return true;
      }
    }

    return false;
  }
}

==> navigine_sdk-1.2.4%2B3.tar.gz: lib/models/device_info.dart <==
part of navigine_sdk;

class DeviceInfo {
  String id = "";
  int location = 0;
  int subLocation = 0;
  num x = 0.0;
  num y = 0.0;
  num r = 0.0;
  num azimuth = 0.0;
  num? stepLength = 0.0;
  int? stepCount = 0;
  int? errorCode = 0;
  List<RoutePath> paths = [];
  List<Zone> zones = [];
  num latitude = 0;
  num longitude = 0;

// flutter: {x: 128.38, zones: [], y: 167.42, subLocation: 144745, location: 102126, r: 1.5, azimuth: 2.2300000190734863, id: 30CCBB0E-2507-4BAD-B7F4-2259ECF88A2A, paths: []}
  static DeviceInfo fromMap(data) {
    DeviceInfo di = DeviceInfo();
    di.azimuth = data["azimuth"] as num;
    di.errorCode = data["errorCode"] as int?;
    di.id = data["id"] as String;
    di.location = data["location"] as int;
    di.r = data["r"] as num;
    di.stepCount = data["stepCount"] as int?;
    di.subLocation = data["subLocation"] as int;
    di.stepLength = data["stepLength"] as num?;

    di.x = data["x"] as num;
    di.y = data["y"] as num;

    for (var zone in data["zones"]) {
      di.zones.add(Zone.fromMap(zone));
    }

    for (var path in data["paths"]) {
      di.paths.add(RoutePath.fromMap(path));
    }

    return di;
  }

  bool isValid() {
    return this.location > 0 && this.subLocation > 0 && this.errorCode == 0;
  }

  LocationPoint? getLocationPoint() {
    return this.isValid()
        ? LocationPoint.fromData(
            this.location, this.subLocation, this.x, this.y)
        : null;
  }

  GlobalPoint? getGlobalPoint() {
    return this.isValid()
        ? GlobalPoint.fromValue(this.latitude, this.longitude)
        : null;
  }

  bool inZoneInId(int id) {
    for (int i = 0; i < this.zones.length; ++i) {
      if ((this.zones[i]).id == id) {
        return true;
      }
    }

    return false;
  }

  bool inZoneInAlias(String alias) {
    for (int i = 0; i < this.zones.length; ++i) {
      if ((this.zones[i]).alias == alias) {
        return true;
      }
    }

    return false;
  }
}
